import axios from "axios";

const backendUrl = '/backend/'
const geoServerUrl = '/geoserver/'

export const instance = axios.create({
    baseURL: backendUrl
})

export const URL_MAP = {
    DEVICE_LIST: 'device/',
    DEVICE_DETAIL: 'device/detail/',
    PROJECT_LIST: 'project/',
    PROJECT_DETAIL: 'project/detail/',
    SENSOR_LIST: 'sensor/',
    SENSOR_DETAIL: 'sensor/detail/',
    WATER_LIST: 'v1/api/water_detail/',
    USER_LIST: 'user/',
    USER_DETAIL: 'user/detail/',
    CHANGE_PASSWD: 'current/chpass/',
    RESET_PASSWD: 'passwd/reset/',
    POSITION_LIST: 'position/',
    POSITION_DETAIL: 'position/detail/'

}

export async function login(username, passwd, uuid, capthe)
{
    let response = await instance.post('auth', {
        'username':username,
        'password':passwd,
        'uuid':uuid,
        'captch':capthe
    })
    let data = await response.data
    let token = data.access_token
    instance.defaults.headers['Authorization'] = "JWT " + token;

    response = await instance.get('current/')
    data = await response.data
    data.token = token
    return data
}

export function setAuth(auth) {
    instance.defaults.headers['Authorization'] = 'JWT ' + auth;
}

export async function logout()
{
    instance.defaults.headers['Authorization'] = ''
}

export async function getData(url, json) {
    let response = await instance.get(url, {
        params: json
    })
    
    let data = await response.data
    return data
}

export async function postJSON(url, json) {
    const headerJSON = {
        "Content-Type": "application/json"
      };
    let response = await instance.post(url, JSON.stringify(json), { headers: headerJSON })
    let data = await response.data
    return data
}

export async function putJSON(url, json) {
    const headerJSON = {
        "Content-Type": "application/json"
      };
    let response = await instance.put(url, JSON.stringify(json), { headers: headerJSON })
    let data = await response.data
    return data
}

export async function patchJSON(url, json) {
    const headerJSON = {
        "Content-Type": "application/json"
      };
    let response = await instance.patch(url, JSON.stringify(json), { headers: headerJSON })
    let data = await response.data
    return data
}

export async function deleteJSON(url, json) {
    const headerJSON = {
        "Content-Type": "application/json"
      };
    let response = await instance.delete(url, { data:json })
    let data = await response.data
    return data
}